@@ -33,11 +33,19 @@ tournament_query_by_event_id = """
         }
     }
 """
+tournaments_base_query = """
+  query Tournaments(QUERY_PARAMS) {
+    event(SEARCH_BY) {
+      RESPONSE_KEYS
+    }
+  }
+"""
 
 query_by_distance = """
-  query Tournaments($perPage: Int, $coordinates: String!, $radius: String!) {
+  query Tournaments($page: Int!, $perPage: Int, $coordinates: String!, $radius: String!) {
     tournaments(query: {
       perPage: $perPage
+      page: $page
       filter: {
         location: {
           distanceFrom: $coordinates,
@@ -45,13 +53,20 @@ query_by_distance = """
         }
       }
     }) {
+      pageInfo {
+          total
+          totalPages
+      }
       nodes {
         id
         name
         city
         numAttendees
         slug
+        createdAt
         endAt
+        images { id }
+        links { facebook discord }
       }
     }
   }"""
@@ -75,7 +90,10 @@ query_by_distance_and_time = """
         city
         numAttendees
         slug
+        createdAt
         endAt
+        images { id }
+        links { facebook discord }
       }
     }
   }
@@ -88,6 +106,13 @@ base_query_tournaments = """
     }
   }"""
 
+event_base_query = """
+  query EventEntrants(QUERY_PARAMS) {
+    event(SEARCH_BY) {
+      RESPONSE_KEYS
+    }
+  }
+"""
 event_entrants_query = """
   query EventEntrants($eventId: ID!, $page: Int!, $perPage: Int!) {
     event(id: $eventId) {
